c            treat interaction of MovedTrack for non e,g
c
      subroutine cinteNEP
      implicit none

#include  "Zcode.h"
#include  "Ztrack.h"
#include  "Ztrackv.h"
c
c
c          used to judge if user hook should be called 
c          after MovedTrack interacted.
c
c
      character*80 msg
c
c   **  ptcl stacking is done in each subroutine; should be changed
c           (except for hadronic interactions)



         if(MovedTrack.p.code .eq. kpion) then
            call cintePion
         elseif(MovedTrack.p.code .eq. kkaon) then
            call cinteKaon
         elseif(MovedTrack.p.code .eq. knuc) then
            call cinteNuc
         elseif(MovedTrack.p.code .eq. kmuon) then
            call cinteMuon
         elseif(MovedTrack.p.code .ge. kdeut .and.
     *           MovedTrack.p.code .le. khvymax  ) then
            call cinteHeavy
         elseif(MovedTrack.p.code .eq. ktriton) then
            call cinteHeavy
         elseif(MovedTrack.p.code .eq. kdmes ) then
            call cinteDmes
         elseif(MovedTrack.p.code .eq. knnb) then
            call cintennb
         elseif(MovedTrack.p.code .eq. kddb) then
            call cinteddb
         elseif(MovedTrack.p.code .eq. keta) then
            call cinteEta
         else
            write(msg, *) ' ptcl =', MovedTrack.p.code,
     *        ' interaction=', 
     *         IntInfArray(ProcessNo).process,
     *        ' should not occure'
            call cerrorMsg(msg, 0)
         endif
       end     
